pub struct Results {
pub cluster: ClusterFindings,
pub subnets: SubnetFindings,
pub data_plane: DataPlaneFindings,
pub addons: AddonFindings,
pub kubernetes: KubernetesFindings,
pub kubernetes_suppressed: KubernetesSuppressed,
pub service_limits: ServiceLimitFindings,
pub insights: InsightsFindings,
}Expand description
Container of all findings collected
Fields
cluster: ClusterFindingssubnets: SubnetFindingsdata_plane: DataPlaneFindingsaddons: AddonFindingskubernetes: KubernetesFindingskubernetes_suppressed: KubernetesSuppressedservice_limits: ServiceLimitFindingsinsights: InsightsFindingsImplementations
Sourceimpl Results
impl Results
Sourcepub fn filter_recommended(&mut self)
pub fn filter_recommended(&mut self)
Remove all findings where remediation is Recommended, keeping only Required
Sourcepub fn to_stdout_table(&self, show_suppressed: bool) -> Result<String>
pub fn to_stdout_table(&self, show_suppressed: bool) -> Result<String>
Renders all findings as a formatted stdout table string