pub fn load(path: Option<&str>) -> Result<Config>
Load configuration from an explicit path, the default .eksup.yaml in the current working directory, or fall back to Config::default().
.eksup.yaml
Config::default()