pub struct ManagedNodeGroupUpdate {
pub finding: Finding,
pub name: String,
pub autoscaling_group_name: String,
pub launch_template: LaunchTemplate,
}Fields
finding: Findingname: StringEKS managed node group name
autoscaling_group_name: StringName of the autoscaling group associated to the EKS managed node group
launch_template: LaunchTemplateLaunch template controlled by users that influences the autoscaling group
This distinction is important because we only consider the launch templates provided by users and not provided by EKS managed node group(s)